@@ -11,8 +11,8 @@ function initialize!(integrator, cache::ABDF2ConstantCache)
 end
 
 @muladd function perform_step!(integrator, cache::ABDF2ConstantCache, repeat_step = false)
-    @unpack t, f, p = integrator
-    @unpack dtₙ₋₁, nlsolver = cache
+    (; t, f, p) = integrator
+    (; dtₙ₋₁, nlsolver) = cache
     alg = unwrap_alg(integrator, true)
     dtₙ, uₙ, uₙ₋₁, uₙ₋₂ = integrator.dt, integrator.u, integrator.uprev, integrator.uprev2
 
@@ -95,10 +95,10 @@ function initialize!(integrator, cache::ABDF2Cache)
 end
 
 @muladd function perform_step!(integrator, cache::ABDF2Cache, repeat_step = false)
-    @unpack t, dt, f, p = integrator
+    (; t, dt, f, p) = integrator
     #TODO: remove zₙ₋₁ from the cache
-    @unpack atmp, dtₙ₋₁, zₙ₋₁, nlsolver, step_limiter! = cache
-    @unpack z, tmp, ztmp = nlsolver
+    (; atmp, dtₙ₋₁, zₙ₋₁, nlsolver, step_limiter!) = cache
+    (; z, tmp, ztmp) = nlsolver
     alg = unwrap_alg(integrator, true)
     uₙ, uₙ₋₁, uₙ₋₂, dtₙ = integrator.u, integrator.uprev, integrator.uprev2, integrator.dt
 
@@ -175,8 +175,8 @@ end
 # SBDF
 
 function initialize!(integrator, cache::SBDFConstantCache)
-    @unpack uprev, p, t = integrator
-    @unpack f1, f2 = integrator.f
+    (; uprev, p, t) = integrator
+    (; f1, f2) = integrator.f
     integrator.kshortsize = 2
     integrator.k = typeof(integrator.k)(undef, integrator.kshortsize)
     cache.du₁ = f1(uprev, p, t)
@@ -192,10 +192,10 @@ function initialize!(integrator, cache::SBDFConstantCache)
 end
 
 function perform_step!(integrator, cache::SBDFConstantCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     alg = unwrap_alg(integrator, true)
-    @unpack uprev2, uprev3, uprev4, du₁, du₂, k₁, k₂, k₃, nlsolver = cache
-    @unpack f1, f2 = integrator.f
+    (; uprev2, uprev3, uprev4, du₁, du₂, k₁, k₂, k₃, nlsolver) = cache
+    (; f1, f2) = integrator.f
     cnt = cache.cnt = min(alg.order, integrator.iter + 1)
     integrator.iter == 1 && !integrator.u_modified && (cnt = cache.cnt = 1)
     nlsolver.γ = γ = inv(γₖ[cnt])
@@ -251,8 +251,8 @@ function perform_step!(integrator, cache::SBDFConstantCache, repeat_step = false
 end
 
 function initialize!(integrator, cache::SBDFCache)
-    @unpack uprev, p, t = integrator
-    @unpack f1, f2 = integrator.f
+    (; uprev, p, t) = integrator
+    (; f1, f2) = integrator.f
     integrator.kshortsize = 2
 
     resize!(integrator.k, integrator.kshortsize)
@@ -266,11 +266,11 @@ function initialize!(integrator, cache::SBDFCache)
 end
 
 function perform_step!(integrator, cache::SBDFCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     alg = unwrap_alg(integrator, true)
-    @unpack uprev2, uprev3, uprev4, k₁, k₂, k₃, du₁, du₂, nlsolver = cache
-    @unpack tmp, z = nlsolver
-    @unpack f1, f2 = integrator.f
+    (; uprev2, uprev3, uprev4, k₁, k₂, k₃, du₁, du₂, nlsolver) = cache
+    (; tmp, z) = nlsolver
+    (; f1, f2) = integrator.f
     cnt = cache.cnt = min(alg.order, integrator.iter + 1)
     integrator.iter == 1 && !integrator.u_modified && (cnt = cache.cnt = 1)
     nlsolver.γ = γ = inv(γₖ[cnt])
@@ -335,8 +335,8 @@ function initialize!(integrator, cache::QNDF1ConstantCache)
 end
 
 function perform_step!(integrator, cache::QNDF1ConstantCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack uprev2, D, D2, R, U, dtₙ₋₁, nlsolver = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; uprev2, D, D2, R, U, dtₙ₋₁, nlsolver) = cache
     alg = unwrap_alg(integrator, true)
     κ = alg.kappa
     cnt = integrator.iter
@@ -419,9 +419,9 @@ function initialize!(integrator, cache::QNDF1Cache)
 end
 
 function perform_step!(integrator, cache::QNDF1Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack uprev2, D, D2, R, U, dtₙ₋₁, utilde, atmp, nlsolver, step_limiter! = cache
-    @unpack z, tmp, ztmp = nlsolver
+    (; t, dt, uprev, u, f, p) = integrator
+    (; uprev2, D, D2, R, U, dtₙ₋₁, utilde, atmp, nlsolver, step_limiter!) = cache
+    (; z, tmp, ztmp) = nlsolver
     alg = unwrap_alg(integrator, true)
     κ = alg.kappa
     cnt = integrator.iter
@@ -506,8 +506,8 @@ function initialize!(integrator, cache::QNDF2ConstantCache)
 end
 
 function perform_step!(integrator, cache::QNDF2ConstantCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack uprev2, uprev3, dtₙ₋₁, dtₙ₋₂, D, D2, R, U, nlsolver = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; uprev2, uprev3, dtₙ₋₁, dtₙ₋₂, D, D2, R, U, nlsolver) = cache
     alg = unwrap_alg(integrator, true)
     cnt = integrator.iter
     k = 2
@@ -614,10 +614,10 @@ function initialize!(integrator, cache::QNDF2Cache)
 end
 
 function perform_step!(integrator, cache::QNDF2Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack uprev2, uprev3, dtₙ₋₁, dtₙ₋₂, D, D2, R, U, utilde, atmp, nlsolver,
-    step_limiter! = cache
-    @unpack z, tmp, ztmp = nlsolver
+    (; t, dt, uprev, u, f, p) = integrator
+    (; uprev2, uprev3, dtₙ₋₁, dtₙ₋₂, D, D2, R, U, utilde, atmp, nlsolver,
+    step_limiter!) = cache
+    (; z, tmp, ztmp) = nlsolver
     alg = unwrap_alg(integrator, true)
     cnt = integrator.iter
     k = 2
@@ -727,8 +727,8 @@ end
 
 function perform_step!(integrator, cache::QNDFConstantCache{max_order},
         repeat_step = false) where {max_order}
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack dtprev, order, D, U, nlsolver, γₖ = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; dtprev, order, D, U, nlsolver, γₖ) = cache
     alg = unwrap_alg(integrator, true)
 
     if integrator.u_modified
@@ -749,7 +749,7 @@ function perform_step!(integrator, cache::QNDFConstantCache{max_order},
     if dt != dtprev || cache.prevorder != k
         ρ = dt / dtprev
         integrator.cache.nconsteps = 0
-        @unpack U = cache
+        (; U) = cache
         R = calc_R(ρ, k, Val(max_order))
         RU = R * U
         Dtmp = D[:, 1:k] * RU[1:k, 1:k]
@@ -793,7 +793,7 @@ function perform_step!(integrator, cache::QNDFConstantCache{max_order},
     update_D!(D, dd, k)
 
     if integrator.opts.adaptive
-        @unpack abstol, reltol, internalnorm = integrator.opts
+        (; abstol, reltol, internalnorm) = integrator.opts
         if cache.consfailcnt > 1 && mass_matrix !== I
             # if we get repeated failure and mass_matrix !== I it's likely that
             # there's a discontinuity on the algebraic equations
@@ -841,9 +841,9 @@ end
 
 function perform_step!(integrator, cache::QNDFCache{max_order},
         repeat_step = false) where {max_order}
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack dtprev, order, D, nlsolver, γₖ, dd, atmp, atmpm1, atmpp1,
-    utilde, utildem1, utildep1, ϕ, u₀, step_limiter! = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; dtprev, order, D, nlsolver, γₖ, dd, atmp, atmpm1, atmpp1,
+    utilde, utildem1, utildep1, ϕ, u₀, step_limiter!) = cache
     alg = unwrap_alg(integrator, true)
 
     if integrator.u_modified
@@ -864,7 +864,7 @@ function perform_step!(integrator, cache::QNDFCache{max_order},
     if dt != dtprev || cache.prevorder != k
         ρ = dt / dtprev
         cache.nconsteps = 0
-        @unpack RU, U, Dtmp = cache
+        (; RU, U, Dtmp) = cache
         R = calc_R(ρ, k, Val(max_order))
         copyto!(RU, R * U)
         @views mul!(Dtmp[:, 1:k], D[:, 1:k], RU[1:k, 1:k])
@@ -898,7 +898,7 @@ function perform_step!(integrator, cache::QNDFCache{max_order},
     if mass_matrix === I
         @.. broadcast=false nlsolver.tmp=(u₀/β₀-ϕ)/dt
     else
-        @unpack tmp2 = cache
+        (; tmp2) = cache
         @.. broadcast=false tmp2=(u₀/β₀-ϕ)/dt
         mul!(nlsolver.tmp, mass_matrix, tmp2)
     end
@@ -916,7 +916,7 @@ function perform_step!(integrator, cache::QNDFCache{max_order},
     step_limiter!(u, integrator, p, t + dt)
 
     if integrator.opts.adaptive
-        @unpack abstol, reltol, internalnorm = integrator.opts
+        (; abstol, reltol, internalnorm) = integrator.opts
         if cache.consfailcnt > 1 && mass_matrix !== I
             # if we get repeated failure and mass_matrix !== I it's likely that
             # there's a discontinuity on the algebraic equations
@@ -965,7 +965,7 @@ function initialize!(integrator, cache::MEBDF2ConstantCache)
 end
 
 @muladd function perform_step!(integrator, cache::MEBDF2ConstantCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     nlsolver = cache.nlsolver
     alg = unwrap_alg(integrator, true)
     markfirststage!(nlsolver)
@@ -1017,8 +1017,8 @@ function initialize!(integrator, cache::MEBDF2Cache)
 end
 
 @muladd function perform_step!(integrator, cache::MEBDF2Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack z₁, z₂, tmp2, nlsolver = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; z₁, z₂, tmp2, nlsolver) = cache
     z = nlsolver.z
     mass_matrix = integrator.f.mass_matrix
     alg = unwrap_alg(integrator, true)
@@ -1077,9 +1077,9 @@ end
 
 function perform_step!(integrator, cache::FBDFConstantCache{max_order},
         repeat_step = false) where {max_order}
-    @unpack ts, u_history, order, u_corrector, bdf_coeffs, r, nlsolver,
-    weights, ts_tmp, iters_from_event, nconsteps = cache
-    @unpack t, dt, u, f, p, uprev = integrator
+    (; ts, u_history, order, u_corrector, bdf_coeffs, r, nlsolver,
+    weights, ts_tmp, iters_from_event, nconsteps) = cache
+    (; t, dt, u, f, p, uprev) = integrator
 
     tdt = t + dt
     k = order
@@ -1239,9 +1239,9 @@ end
 
 function perform_step!(integrator, cache::FBDFCache{max_order},
         repeat_step = false) where {max_order}
-    @unpack ts, u_history, order, u_corrector, bdf_coeffs, r, nlsolver, weights, terk_tmp,
-    terkp1_tmp, atmp, tmp, equi_ts, u₀, ts_tmp, step_limiter! = cache
-    @unpack t, dt, u, f, p, uprev = integrator
+    (; ts, u_history, order, u_corrector, bdf_coeffs, r, nlsolver, weights, terk_tmp,
+    terkp1_tmp, atmp, tmp, equi_ts, u₀, ts_tmp, step_limiter!) = cache
+    (; t, dt, u, f, p, uprev) = integrator
 
     reinitFBDF!(integrator, cache)
     k = order
@@ -1310,7 +1310,7 @@ function perform_step!(integrator, cache::FBDFCache{max_order},
     end
     @.. broadcast=false terk_tmp=lte*terkp1_tmp
     if integrator.opts.adaptive
-        @unpack abstol, reltol, internalnorm = integrator.opts
+        (; abstol, reltol, internalnorm) = integrator.opts
         for i in 1:(k + 1)
             ts_tmp[i + 1] = ts[i]
         end
